@@ -4,7 +4,8 @@ require 'transformer/syskit/extensions/component_model'
 require 'transformer/syskit/extensions/component'
 require 'transformer/syskit/extensions/composition'
 require 'transformer/syskit/extensions/device'
-require 'transformer/syskit/extensions/engine'
+require 'transformer/syskit/extensions/master_device'
+require 'transformer/syskit/extensions/system_network_generator'
 require 'transformer/syskit/extensions/graphviz'
 require 'transformer/syskit/extensions/instance_requirements'
 require 'transformer/syskit/extensions/plan'
@@ -12,4 +13,5 @@ require 'transformer/syskit/extensions/task_context'
 require 'transformer/syskit/extensions/task_context_model'
 require 'transformer/syskit/extensions/configuration'
 require 'transformer/syskit/extensions/profile'
+require 'transformer/syskit/extensions/profile_robot_definition'
 require 'transformer/syskit/extensions/port'
